@@ -1,3 +1,5 @@
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
+#
 # Copyright 2002 Ben Escoto
 #
 # This file is part of duplicity.
@@ -150,7 +152,7 @@ class GPGFile:
             if self.status_fp:
                 self.set_signature()
             self.gpg_process.wait()
-        if log.verbosity >= 5:
+        if log.getverbosity() >= 5:
             self.print_log()
         self.logger_fp.close()
         self.closed = 1
